@@ -381,7 +381,9 @@ class SignupForm(BaseSignupForm):
             label=_("Password"), autocomplete="new-password"
         )
         if app_settings.SIGNUP_PASSWORD_ENTER_TWICE:
-            self.fields["password2"] = PasswordField(label=_("Password (again)"))
+            self.fields["password2"] = PasswordField(
+                label=_("Password (again)"), autocomplete="new-password"
+            )
 
         if hasattr(self, "field_order"):
             set_form_field_order(self, self.field_order)
@@ -392,7 +394,8 @@ class SignupForm(BaseSignupForm):
         # `password` cannot be of type `SetPasswordField`, as we don't
         # have a `User` yet. So, let's populate a dummy user to be used
         # for password validaton.
-        dummy_user = get_user_model()
+        User = get_user_model()
+        dummy_user = User()
         user_username(dummy_user, self.cleaned_data.get("username"))
         user_email(dummy_user, self.cleaned_data.get("email"))
         password = self.cleaned_data.get("password1")
@@ -524,18 +527,34 @@ class ResetPasswordForm(forms.Form):
         email = self.cleaned_data["email"]
         email = get_adapter().clean_email(email)
         self.users = filter_users_by_email(email, is_active=True)
-        if not self.users:
+        if not self.users and not app_settings.PREVENT_ENUMERATION:
             raise forms.ValidationError(
                 _("The e-mail address is not assigned to any user account")
             )
         return self.cleaned_data["email"]
 
     def save(self, request, **kwargs):
-        current_site = get_current_site(request)
         email = self.cleaned_data["email"]
+        if not self.users:
+            self._send_unknown_account_mail(request, email)
+        else:
+            self._send_password_reset_mail(request, email, self.users, **kwargs)
+        return email
+
+    def _send_unknown_account_mail(self, request, email):
+        signup_url = build_absolute_uri(request, reverse("account_signup"))
+        context = {
+            "current_site": get_current_site(request),
+            "email": email,
+            "request": request,
+            "signup_url": signup_url,
+        }
+        get_adapter(request).send_mail("account/email/unknown_account", email, context)
+
+    def _send_password_reset_mail(self, request, email, users, **kwargs):
         token_generator = kwargs.get("token_generator", default_token_generator)
 
-        for user in self.users:
+        for user in users:
 
             temp_key = token_generator.make_token(user)
 
@@ -551,7 +570,7 @@ class ResetPasswordForm(forms.Form):
             url = build_absolute_uri(request, path)
 
             context = {
-                "current_site": current_site,
+                "current_site": get_current_site(request),
                 "user": user,
                 "password_reset_url": url,
                 "request": request,
@@ -562,7 +581,6 @@ class ResetPasswordForm(forms.Form):
             get_adapter(request).send_mail(
                 "account/email/password_reset_key", email, context
             )
-        return self.cleaned_data["email"]
 
 
 class ResetPasswordKeyForm(PasswordVerificationMixin, forms.Form):
