@@ -73,12 +73,16 @@ class AppSettings(object):
 
     @property
     def STORE_TOKENS(self):
-        return self._setting("STORE_TOKENS", True)
+        return self._setting("STORE_TOKENS", False)
 
     @property
     def UID_MAX_LENGTH(self):
         return 191
 
+    @property
+    def SOCIALACCOUNT_STR(self):
+        return self._setting("SOCIALACCOUNT_STR", None)
+
 
 # Ugly? Guido recommends this himself ...
 # http://mail.python.org/pipermail/python-ideas/2012-May/014969.html
