@@ -1,12 +1,16 @@
-from allauth.socialaccount.tests import create_oauth2_tests
-from allauth.tests import MockedResponse
-from allauth.socialaccount.providers import registry
+from allauth.socialaccount.tests import OAuth2TestsMixin
+from allauth.tests import MockedResponse, TestCase
 
 from .provider import CoinbaseProvider
 
-class CoinbaseTests(create_oauth2_tests(registry.by_id(CoinbaseProvider.id))):
+
+class CoinbaseTests(OAuth2TestsMixin, TestCase):
+    provider_id = CoinbaseProvider.id
+
     def get_mocked_response(self):
-        return MockedResponse(200, """
+        return MockedResponse(
+            200,
+            """
 {
   "users": [
     {
@@ -42,4 +46,5 @@ class CoinbaseTests(create_oauth2_tests(registry.by_id(CoinbaseProvider.id))):
     }
   ]
 }
-        """)
+        """,
+        )
