@@ -633,3 +633,21 @@ class SocialAccountTests(TestCase):
 
         resp = self.client.get(reverse("socialaccount_signup"))
         self.assertRedirects(resp, reverse("account_login"))
+
+    def test_social_account_str_default(self):
+        User = get_user_model()
+        user = User(username="test")
+        sa = SocialAccount(user=user)
+        self.assertEqual("test", str(sa))
+
+    def socialaccount_str_custom_formatter(socialaccount):
+        return "A custom str builder for {}".format(socialaccount.user)
+
+    @override_settings(
+        SOCIALACCOUNT_SOCIALACCOUNT_STR=socialaccount_str_custom_formatter
+    )
+    def test_social_account_str_customized(self):
+        User = get_user_model()
+        user = User(username="test")
+        sa = SocialAccount(user=user)
+        self.assertEqual("A custom str builder for test", str(sa))
